@@ -1,11 +1,9 @@
-# Copyright (C) 2020-2021
-# Author: Cesar Roman
-# Contact: cesar@thecesrom.dev
-
 """Date module."""
 
 __all__ = ["compare"]
 
+from java.util import Date
+
 
 def compare(date_1, date_2):
     """Compare two dates.
