@@ -1,9 +1,7 @@
-# Copyright (C) 2020-2021
-# Author: Cesar Roman
-# Contact: cesar@thecesrom.dev
-
 """GUI module."""
 
+from __future__ import unicode_literals
+
 __all__ = ["confirm", "error", "info", "input", "warning"]
 
 import system.util
@@ -11,22 +9,6 @@ from javax.swing import JLabel, JOptionPane, JPanel, JTextField
 
 from incendium import constants
 
-# Cursor codes.
-CURSOR_DEFAULT = 0
-CURSOR_CROSSHAIR = 1
-CURSOR_TEXT = 2
-CURSOR_WAIT = 3
-CURSOR_HAND = 4
-CURSOR_MOVE = 5
-CURSOR_SW_RESIZE = 6
-CURSOR_SE_RESIZE = 7
-CURSOR_NW_RESIZE = 8
-CURSOR_NE_RESIZE = 9
-CURSOR_N_RESIZE = 10
-CURSOR_S_RESIZE = 11
-CURSOR_W_RESIZE = 12
-CURSOR_E_RESIZE = 13
-
 
 def confirm(message, title="Confirm", show_cancel=False):
     """Display a confirmation dialog box to the user.
